==> grunt-modernizr-0.5.2.tgz: package/test/js/vanilla.js <==
/*jshint browser:true*/
var Modernizr = window.Modernizr;

var tests = {
	"canvastext" : Modernizr.canvastext,
	"csstransforms3d": Modernizr.csstransforms3d,
	"flexbox": Modernizr["flexbox"],
	"cssgradients": Modernizr.cssgradients,
	"opacity": Modernizr.opacity,
	"indexedDB": Modernizr.indexedDB,
	"backgroundsize": Modernizr.backgroundsize,
	"borderimage": Modernizr.borderimage,
	"borderradius": Modernizr.borderradius,
	"boxshadow": Modernizr.boxshadow,
	"cssanimations": Modernizr.cssanimations,
	"csscolumns": Modernizr.csscolumns,
	"cssreflections": Modernizr.cssreflections,
	"csstransitions": Modernizr.csstransitions,
	"testallprops": Modernizr.testallprops,
	"flexboxlegacy": Modernizr["flexboxlegacy"],
	"prefixed": Modernizr.prefixed,
	"csstransforms": Modernizr.csstransforms,
	"mq": Modernizr.mq,
	"hashchange": Modernizr.hashchange,
	"draganddrop": Modernizr.draganddrop,
	"generatedcontent": Modernizr.generatedcontent,
	"svg": Modernizr.svg,
	"inlinesvg": Modernizr.inlinesvg,
	"smil": Modernizr.smil,
	"svgclippaths": Modernizr.svgclippaths,
	"input": Modernizr.input,
	"inputtypes": Modernizr.inputtypes,
	"touch": Modernizr.touch,
	"fontface": Modernizr.fontface,
	"testbundle": Modernizr.testbundle,
	"respond": Modernizr.respond,
	"websockets": Modernizr.websockets,
	"applicationcache": Modernizr.applicationcache,
	"audio": Modernizr.audio,
	"canvas": Modernizr.canvas,
	"geolocation": Modernizr.geolocation,
	"history": Modernizr.history,
	"hsla": Modernizr.hsla,
	"indexeddb": Modernizr.indexeddb,
	"localstorage": Modernizr.localstorage,
	"multiplebgs": Modernizr.multiplebgs,
	"postmessage": Modernizr.postmessage,
	"scriptdefer": Modernizr.scriptdefer,
	"sessionstorage": Modernizr.sessionstorage,
	"textshadow": Modernizr["textshadow"],
	"rgba": Modernizr.rgba,
	"video": Modernizr.video,
	"webgl": Modernizr.webgl,
	"websqldatabase": Modernizr.websqldatabase,
	"webworkers": Modernizr.webworkers
};

var community = {
	"contextmenu": Modernizr.contextmenu,
	"emoji": Modernizr["emoji"],
	"json": Modernizr.json
};

==> grunt-modernizr-1.0.2.tgz: package/test/js/vanilla.js <==
/*jshint browser:true*/
var Modernizr = window.Modernizr;

var tests = {
	"canvastext" : Modernizr.canvastext,
	"csstransforms3d": Modernizr.csstransforms3d,
	"flexbox": Modernizr["flexbox"],
	"cssgradients": Modernizr.cssgradients,
	"opacity": Modernizr.opacity,
	"indexedDB": Modernizr.indexedDB,
	"backgroundsize": Modernizr.backgroundsize,
	"borderimage": Modernizr.borderimage,
	"borderradius": Modernizr.borderradius,
	"boxshadow": Modernizr.boxshadow,
	"cssanimations": Modernizr.cssanimations,
	"csscolumns": Modernizr.csscolumns,
	"cssreflections": Modernizr.cssreflections,
	"csstransitions": Modernizr.csstransitions,
	"testallprops": Modernizr.testallprops,
	"flexboxlegacy": Modernizr["flexboxlegacy"],
	"prefixed": Modernizr.prefixed,
	"csstransforms": Modernizr.csstransforms,
	"mq": Modernizr.mq,
	"hashchange": Modernizr.hashchange,
	"draganddrop": Modernizr.draganddrop,
	"generatedcontent": Modernizr.generatedcontent,
	"svg": Modernizr.svg,
	"inlinesvg": Modernizr.inlinesvg,
	"smil": Modernizr.smil,
	"svgclippaths": Modernizr.svgclippaths,
	"input": Modernizr.input,
	"inputtypes": Modernizr.inputtypes,
	"touch": Modernizr.touch,
	"fontface": Modernizr.fontface,
	"testbundle": Modernizr.testbundle,
	"respond": Modernizr.respond,
	"websockets": Modernizr.websockets,
	"applicationcache": Modernizr.applicationcache,
	"audio": Modernizr.audio,
	"canvas": Modernizr.canvas,
	"geolocation": Modernizr.geolocation,
	"history": Modernizr.history,
	"hsla": Modernizr.hsla,
	"indexeddb": Modernizr.indexeddb,
	"localstorage": Modernizr.localstorage,
	"multiplebgs": Modernizr.multiplebgs,
	"postmessage": Modernizr.postmessage,
	"scriptdefer": Modernizr.scriptdefer,
	"sessionstorage": Modernizr.sessionstorage,
	"textshadow": Modernizr["textshadow"],
	"rgba": Modernizr.rgba,
	"video": Modernizr.video,
	"webgl": Modernizr.webgl,
	"websqldatabase": Modernizr.websqldatabase,
	"webworkers": Modernizr.webworkers
};

var community = {
	"contextmenu": Modernizr.contextmenu,
	"emoji": Modernizr["emoji"],
	"json": Modernizr.json,
	"battery": Modernizr.battery,
	"csspositionsticky": Modernizr.csspositionsticky,
	"bgrepeatround": Modernizr.bgrepeatround,
	"bgsizecover": Modernizr.bgsizecover,
	"placeholder": Modernizr["placeholder"]
};
